<!-- vale off -->
# Figure functions
API reference for all pre-defined [`CapturedCallable`][vizro.models.types.CapturedCallable] figure functions to be used in the
[`Figure`][vizro.models.Figure]. The [how-to guide on figures](../user-guides/figure.md) contains more information.

::: vizro.figures
    options:
      show_source: true

<!-- vale on -->
